@@ -12,6 +12,8 @@ class Query(Table, Monad):
         self.leftjoin = leftjoin
     
     def __repr__(self):
+        if hasattr(self, 'data'):
+            return self.data.head()
         return f"Query(columns= {self.columns}, \n      joincond= {self.joincond}, \n      groupbys= {self.groupbys}, \n      memloc= '{memloc(self)}')"
     
     def __rshift__(self, func):
@@ -118,6 +120,9 @@ class Query(Table, Monad):
     def allDescendants(self):
         return self.allExprs().bind(lambda x: L(x) + x.descendants())
     
+    def allBaseExprs(self):
+        return self.allDescendants().filter(lambda x: type(x) is BaseExpr)
+    
     def setSource(self, newtable, oldtable=None):
         self.modify(lambda x: x.setSource(newtable, oldtable))
     
@@ -277,7 +282,7 @@ class Query(Table, Monad):
         # return lens.columns.modify(lambda x: ffunc(x, *args, **kwargs))(self).joinM()
     
     
-    def exists(self, col=False, _func='notnull_', out='col'):
+    def exists(self, out='col', col=False, _func='notnull_'):
         
         alias = self.columns.__class__.__name__.lower()
         
