@@ -217,13 +217,18 @@ def canMoveOut(table, inner, outer):
     # shouldmove = table.parents.filter(lambda x: outer in x.parents).len() > 1
     
     # NEW: just move if it's either an outer groupby or joined to an outer groupby, and the same is not true for inner
-    willmove = table in outer.groupbys.getTables() + outer.getTables().filter(lambda x: x.isJoined(outer.joincond.children))
+    # willmove = table in outer.groupbys.getTables() + outer.getTables().filter(lambda x: x.isJoined(outer.joincond.children))
+    
+    willmove = inner.allBaseExprs().filter(lambda x: x.table == table and isGrouped(x, outer))
+    
     isgroupedinner = table in inner.groupbys.getTables() #+ inner.getTables().filter(lambda x: x.isJoined(inner.joincond.children))
     
     # can't move out anything that appears in an agg expr
     canmove = not inner.allExprs().filter(lambda x: x.isagg()).getTables()\
                 <= inner.allExprs().filter(lambda x: table in x.getTables()).getTables()
     
+    
+    
     return willmove and not inner.leftjoin and (not isgroupedinner) and canmove # and isisolated 
 
 
@@ -462,6 +467,7 @@ def canMergeTable(tab0, tab1, subquery=False):
     if tab1 not in tab0.getTables() and tab0 not in tab1.getTables():
         tab11 = copy(tab1)
         tab00 = copy(tab0)
+        
         return (tab00 @ tab11).aggedTables() == tab00.aggedTables()
     
     go = (tab0.groupbys <= tab1.groupbys and tab0 in tab1.getTables() and not isSum(tab0) and not isSum(tab1)) or \
